OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Användarsessionen upphörde oväntat",
    "Provided email-address is not valid" : "Den angivna e-postadressen är inte giltig",
    "%s has published the calendar »%s«" : "%s har publicerat kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Oväntat fel vid skickande av e-post. Kontakta din administratör.",
    "Successfully sent email to " : "Skickade e-post till",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi vill informera dig att %s har publicerat kalendern »%s«.",
    "Open »%s«" : "Öppna »%s«",
    "Cheers!" : "Ha de fint!",
    "Upcoming events" : "Kommande händelser",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
    "Previous day" : "Föregående dag",
    "Previous week" : "Föregående vecka",
    "Previous month" : "Föregående månad",
    "Next day" : "Nästa dag",
    "Next week" : "Nästa vecka",
    "Next month" : "Nästa månad",
    "+ New event" : "+ Ny händelse",
    "Today" : "Idag",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "List" : "Lista",
    "Untitled calendar" : "Namnlös kalender",
    "Edit name" : "Ändra namn",
    "Saving name …" : "Sparar namn …",
    "Edit color" : "Ändra färg",
    "Saving color …" : "Sparar färg …",
    "Copy private link" : "Kopiera privat länk",
    "Download" : "Hämta",
    "Unshare from me" : "Sluta dela från mig",
    "Delete" : "Ta bort",
    "An error occurred, unable to change visibility of the calendar." : "Ett fel inträffade, kunde inte ändra synlighet på kalendern.",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "An error occurred, unable to rename the calendar." : "Ett fel inträffade, kunde inte byta namn på kalendern.",
    "An error occurred, unable to change the calendar's color." : "Ett fel inträffade, kunde inte byta färg på kalendern.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Slutar dela kalendern om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Raderar kalendern {countdown} sekunder"],
    "Share link" : "Dela länk",
    "Publish calendar" : "Publicera kalender ",
    "Publishing calendar" : "Publicerar kalender",
    "Copy public link" : "Kopiera publik länk",
    "Send link to calendar via email" : "Skicka länk till kalender via e-post",
    "Enter one address" : "Mata in en adress",
    "Sending email …" : "Skickar e-post …",
    "Copy subscription link" : "Kopiera abonnemangslänk",
    "Copying link …" : "Kopierar länk …",
    "Copied link" : "Kopierad länk",
    "Could not copy link" : "Kunde inte kopiera länk",
    "Copy embedding code" : "Kopiera inbäddad kod",
    "Copying code …" : "Kopierar kod …",
    "Copied code" : "Kopierad kod",
    "Could not copy code" : "Kunde inte kopiera kod",
    "Delete share link" : "Ta bort delad länk",
    "Deleting share link …" : "Raderar delad länk …",
    "An error occurred, unable to publish calendar." : "Ett fel inträffade, kunde inte publicera kalendern.",
    "An error occurred, unable to send email." : "Fel uppstod. Mejlet kunde inte skickas.",
    "Embed code copied to clipboard." : "Inbäddad kod kopierad till urklipp.",
    "Embed code could not be copied to clipboard." : "Inbäddad kod kunde inte kopieras till urklipp.",
    "Unpublishing calendar failed" : "Avpublicering av kalendern misslyckades",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "can edit" : "kan redigera",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Fel uppstod. Det gick inte att ta bort kalenderdelningen.",
    "An error occurred, unable to change the permission of the share." : "Ett fel inträffade. Det gick inte att ändra behörighet för delningen.",
    "+ New calendar" : "+ Ny kalender",
    "New calendar" : "Ny kalender",
    "Creating calendar …" : "Skapar kalender …",
    "New calendar with task list" : "Ny kalender med uppgiftslista",
    "New subscription from link (read-only)" : "Ny prenumeration från länk (skrivskyddad)",
    "Creating subscription …" : "Skapar abonnemang …",
    "An error occurred, unable to create the calendar." : "Ett fel inträffade, kunde inte skapa kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Ange en giltig länk (startar med http://, https://, webcal://, eller webcals://)",
    "Could not update calendar order." : "Det gick inte att uppdatera kalenderordningen.",
    "Import calendars" : "Importera kalendrar",
    "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
    "Filename" : "Filnamn",
    "Calendar to import into" : "Kalender att importera till",
    "Cancel" : "Avbryt",
    "_Import calendar_::_Import calendars_" : ["Importera kalender","Importera kalendrar"],
    "{filename} is an unsupported file-type" : "{filename} är en filtyp som inte stöds",
    "{filename} could not be parsed" : "{filename} kunde inte läsas",
    "No valid files found, aborting import" : "Inga giltiga filer hittades, avbryter import",
    "Import partially failed. Imported {accepted} out of {total}." : "Importen misslyckades delvis. Importerade {accepted} av {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Lyckades importera %n händelse","Lyckades importera %n händelser."],
    "Automatic" : "Automatisk",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "New setting was not saved successfully." : "Den nya inställningen kunde inte sparas.",
    "Shortcut overview" : "Översikt av genvägar",
    "or" : "eller",
    "Navigation" : "Navigering",
    "Previous period" : "Föregående period",
    "Next period" : "Nästa period",
    "Views" : "Vyer",
    "Day view" : "Översikt dag",
    "Week view" : "Översikt vecka",
    "Month view" : "Översikt månad",
    "Actions" : "Åtgärder",
    "Create event" : "Skapa händelse",
    "Show shortcuts" : "Visa genvägar",
    "Enable birthday calendar" : "Aktivera födelsedagskalender",
    "Show tasks in calendar" : "Visa uppgifter i kalendern",
    "Enable simplified editor" : "Aktivera förenklad redigerare",
    "Limit visible events per view" : "Begränsa synliga händelser per vy",
    "Show weekends" : "Visa helger",
    "Show week numbers" : "Visa veckonummer",
    "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
    "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
    "Settings & import" : "Inställningar & import",
    "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
    "before at" : "innan",
    "Notification" : "Notifiering",
    "Email" : "E-post",
    "Audio notification" : "Ljudmeddelande",
    "Other notification" : "Annan notifiering",
    "Relative to event" : "I förhållande till händelse",
    "On date" : "På datum",
    "Edit time" : "Ändra tid",
    "Save time" : "Lagra tid",
    "Remove reminder" : "Ta bort påminnelse",
    "on" : "på",
    "at" : "kl",
    "+ Add reminder" : "+Lägg till påminnelse",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minuter"],
    "_hour_::_hours_" : ["timme","timmar"],
    "_day_::_days_" : ["dag","dagar"],
    "_week_::_weeks_" : ["vecka","veckor"],
    "No reminders yet" : "Inga påminnelser ännu",
    "Availability of attendees, resources and rooms" : "Deltagares tillgänglighet, resurser och lokaler",
    "Busy (tentative)" : "Upptagen (preliminär)",
    "Busy" : "Upptagen",
    "Out of office" : "Ej på plats",
    "Unknown" : "Okänd",
    "{name} accepted your invitation." : "{name} accepterade din inbjudan.",
    "{name} accepted {organizerName}'s invitation." : "{name} accepterade {organizerName}'s inbjudan.",
    "{name} declined your invitation." : "{name} avböjde din inbjudan.",
    "{name} declined {organizerName}'s invitation." : "{name} avböjde {organizerName}'s inbjudan.",
    "{name} has delegated their invitation." : "{name} har delegerat sin inbjudan.",
    "{name} marked their participation as tentative." : "{name} markerade sitt deltagande som preliminärt.",
    "{name} did not respond to your invitation yet." : "{name} har inte svarat på din inbjudan ännu.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} har inte svarat på {organizerName}'s inbjudan än.",
    "Create Talk room for this event" : "Skapa ett rum i Talk för denna händelse",
    "Show busy times" : "Visa upptagna tider",
    "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
    "Error creating Talk room" : "Kunde inte skapa rum i Talk",
    "Send e-mail" : "Skicka e-post",
    "Chairperson" : "Ordförande",
    "Required participant" : "Obligatorisk deltagare",
    "Optional participant" : "Valfri deltagare",
    "Non-participant" : "Icke-deltagare",
    "Remove attendee" : "Ta bort deltagaren",
    "Search for e-mails, users, contacts, resources or rooms" : "Sök efter e-post, användare, kontakter, resurser eller rum",
    "No match found" : "Ingen träff",
    "No attendees yet" : "Inga deltagare ännu",
    "(organizer)" : "(arrangör)",
    "Remove color" : "Ta bort färg",
    "Event title" : "Händelsens titel",
    "All day" : "Heldag",
    "Can not modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
    "from {startDate}" : "från {startDate}",
    "from {startDate} at {startTime}" : "från {startDate} kl {startTime}",
    "to {endDate}" : "till {endDate}",
    "to {endDate} at {endTime}" : "till {endDate} kl {endTime}",
    "End repeat" : "Sluta upprepa",
    "Select to end repeat" : "Välj för att avsluta upprepning",
    "never" : "aldrig",
    "on date" : "på datum",
    "after" : "efter",
    "_time_::_times_" : ["gång","gånger"],
    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Den här händelsen är återkommande undantag för en upprepning. Du kan inte lägga till en regel för den.\n ",
    "first" : "första",
    "third" : "tredje",
    "fourth" : "fjärde",
    "fifth" : "femte",
    "second to last" : "näst sist",
    "last" : "sist",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ändringar av återkommande regel gäller endast för denna och alla framtida händelser.",
    "Repeat" : "Upprepa",
    "Repeat every" : "Upprepa varje",
    "By day of the month" : "Efter dag i månaden",
    "On the" : "På den",
    "_month_::_months_" : ["månad","månader"],
    "_year_::_years_" : ["år","år"],
    "Monday" : "Måndag",
    "weekday" : "veckodag",
    "weekend day" : "helgdag",
    "Summary" : "Sammanfattning",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Återkommande definition av denna händelse stöds inte helt av Nextcloud. Om du redigerar återfallsalternativen kan vissa återfall försvinna.",
    "More" : "Mer",
    "Save" : "Spara",
    "Update" : "Uppdatera",
    "Update this occurrence" : "Uppdatera denna förekomst",
    "Update this and all future" : "Uppdatera denna och alla kommande",
    "Public calendar does not exist" : "Publik kalender finns inte",
    "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
    "Please select a timezone:" : "Välj en tidszon:",
    "Pick a time" : "Välj en tidpunkt",
    "Pick a date" : "Välj ett datum",
    "from {formattedDate}" : "från {formattedDate}",
    "to {formattedDate}" : "till {formattedDate}",
    "on {formattedDate}" : "på {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "från {formattedDate} kl {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "till {formattedDate} kl {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "på {formattedDate} kl {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl {formattedTime}",
    "Please enter a valid date" : "Ange ett giltigt datum",
    "Please enter a valid date and time" : "Ange giltigt datum och tid",
    "Type to search timezone" : "Skriv för att söka tidszon",
    "Personal" : "Privat",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Den automatiska tidszon-detekteringen fastställde din tidszon till UTC.\nDetta är troligtvis resultatet av säkerhetsinställningar i din webbläsare.\nStäll in din tidszon manuellt i kalenderinställningarna.",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Din tidszon ({timezoneId}) hittades inte. Återgår till UTC.\nÄndra din tidszon i inställningarna och rapportera detta problem.",
    "No more events today" : "Inga fler händelser idag",
    "No upcoming events" : "Inga kommande händelser",
    "Create a new event" : "Skapa en ny händelse",
    "[Today]" : "[Idag]",
    "[Tomorrow]" : "[Imorgon]",
    "[Yesterday]" : "[Igår]",
    "Event does not exist" : "Händelsen existerar inte",
    "Delete this occurrence" : "Ta bort denna förekomst",
    "Delete this and all future" : "Ta bort denna och alla kommande",
    "Details" : "Detaljer",
    "Attendees" : "Deltagare",
    "Reminders" : "Påminnelser",
    "Close" : "Stäng",
    "Show more details" : "Visa mer information",
    "Subscribe to {name}" : "Prenumerera på {name}",
    "Download {name}" : "Hämta {name}",
    "Anniversary" : "Födelsedag",
    "Appointment" : "Bokning",
    "Business" : "Företag",
    "Education" : "Utbildning",
    "Holiday" : "Ledighet",
    "Meeting" : "Möte",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Icke-arbetstid",
    "Not in office" : "Inte på kontoret",
    "Phone call" : "Telefonsamtal",
    "Sick day" : "Sjukdag",
    "Special occasion" : "Speciellt tillfälle",
    "Travel" : "Resa",
    "Vacation" : "Semester",
    "Midnight on the day the event starts" : "Midnatt den dagen evenemanget börjar",
    "Week {number} of {year}" : "Vecka {number} år {year}",
    "Does not repeat" : "Upprepar inte",
    "Daily" : "Dagligen",
    "Weekly" : "Varje vecka",
    "Monthly" : "Varje månad",
    "Yearly" : "Årligen",
    "_Every %n day_::_Every %n days_" : ["Varje %n dag","Varje %n dagar"],
    "_Every %n week_::_Every %n weeks_" : ["Varje %n vecka","Varje %n veckor"],
    "_Every %n month_::_Every %n months_" : ["Varje %n månad","Varje %n månader"],
    "_Every %n year_::_Every %n years_" : ["Varje %n år","Varje %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dag {dayOfMonthList}","på dagar {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "på den {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "i {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} på den {ordinalNumber} {byDaySet}",
    "Untitled event" : "Namnlös händelse",
    "next year" : "nästa år",
    "today" : "idag",
    "When shared show" : "Visa om delad",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
    "Location" : "Plats",
    "Add a location" : "Lägg till en plats",
    "Description" : "Beskrivning",
    "Add a description" : "Lägg till en beskrivning",
    "Status" : "Status",
    "Confirmed" : "Bekräftad",
    "Tentative" : "Preliminärt",
    "Canceled" : "Avbruten",
    "Confirmation about the overall status of the event." : "Bekräftelse av händelsens övergripande status.",
    "Show as" : "Visa som",
    "Free" : "Ledig",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjälper dig strukturera och organisera dina händelser.",
    "Search or add categories" : "Sök eller lägg till kategorier",
    "Add this as a new category" : "Lägg till som en ny kategori",
    "Custom color" : "Anpassad färg",
    "Special color of this event. Overrides the calendar-color." : "Anpassad färg på denna händelse. Åsidosätter kalenderfärgen.",
    "Imported {filename}" : "Importerad {filename}",
    "Meditation" : "Meditation",
    "Presentation" : "Presentation",
    "Movie" : "Film",
    "Cinema" : "Bio",
    "Review" : "Granska",
    "Office" : "Kontor",
    "Party" : "Fest",
    "Celebration" : "Firande",
    "Mail" : "E-post",
    "Play" : "Spela",
    "Bicycle" : "Cykel",
    "Basketball" : "Basketboll",
    "Studying" : "Studerar",
    "Doctor" : "Läkare",
    "Dentist" : "Tandläkare",
    "Training" : "Träning",
    "Exercise" : "Träning",
    "Barber" : "Frisör",
    "Haircut" : "Frisyr",
    "New Years Eve" : "Nyårsafton",
    "Conference" : "Konferens",
    "Pizza" : "Pizza",
    "Travelling" : "Reser",
    "Lecture" : "Föreläsning",
    "Seminar" : "Seminarium",
    "Golf" : "Golf",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
